@@ -4,13 +4,15 @@ package Devel::NYTProf::FileInfo;    # fid_fileinfo
 
 Devel::NYTProf::FileInfo
 
+=head1 METHODS
+
 =cut
 
 use strict;
 
 use Carp;
 use Config;
-use List::Util qw(sum max);
+use List::Util qw(sum);
 
 use Devel::NYTProf::Util qw(strip_prefix_from_paths trace_level);
 
@@ -128,7 +130,6 @@ sub _add_new_sub_defined {
     $subs_defined->{$subname} = $subinfo;
 }
 
-=head1 METHODS
 
 =head2 sub_call_lines
 
@@ -437,10 +438,6 @@ sub filename_without_inc {
     strip_prefix_from_paths([$self->profile->inc], $f,
         qr/(?: ^ | \[ | \sdefined\sat\s )/x
     );
-    #if ($f->[0] =~ /^\//) {
-    #  warn "filename_without_inc: $f->[0], " .
-    #       "INC=", join(":", $self->profile->inc);
-    #}
     return $f->[0];
 }
 
