@@ -22,7 +22,7 @@ our @EXPORT = qw(
 
 use Devel::NYTProf::Data;
 use Devel::NYTProf::Reader;
-use Devel::NYTProf::Util qw(strip_prefix_from_paths html_safe_filename);
+use Devel::NYTProf::Util qw(html_safe_filename);
 use Devel::NYTProf::Run qw(perl_command_words);
 
 my $diff_opts = ($Config{osname} eq 'MSWin32') ? '-c' : '-u';
@@ -66,7 +66,6 @@ my $text_extn_info = {
     rdt   => { order => 20, tests => ($opts{mergerdt}) ? 2 : 1, },
     x     => { order => 30, tests => 3, },
     calls => { order => 40, tests => 1, },
-    pf    => { order => 50, tests => 2, },
 };
 
 # having t/* in @INC is necessary for prefix-stripping
@@ -87,7 +86,6 @@ my $bindir      = (grep {-d} qw(./blib/script ../blib/script))[0] || do {
 my $nytprofcsv   = File::Spec->catfile($bindir, "nytprofcsv");
 my $nytprofcalls = File::Spec->catfile($bindir, "nytprofcalls");
 my $nytprofhtml  = File::Spec->catfile($bindir, "nytprofhtml");
-my $nytprofpf    = File::Spec->catfile($bindir, "nytprofpf");
 my $nytprofmerge = File::Spec->catfile($bindir, "nytprofmerge");
 
 my $path_sep = $Config{path_sep} || ':';
@@ -162,8 +160,11 @@ sub do_foreach_opt_combination {
 
     my $rusage_start = get_rusage();
 
+    my @combos = $ENV{NYTPROF_TEST_SHORT}
+        ? $opt_combinations->[0]
+        : @$opt_combinations;
     COMBINATION:
-    for my $env (@$opt_combinations) {
+    for my $env (@combos) {
 
         my $prev_failures = count_of_failed_tests();
 
@@ -274,7 +275,8 @@ sub run_test_group {
     my $opts = mk_opt_combinations($extra_options);
     my $tests_per_env = number_of_tests(@tests) + $extra_test_count + 1;
 
-    plan tests => 1 + $tests_per_env * @$opts;
+    my $optscount = $ENV{NYTPROF_TEST_SHORT} ? 1 : @$opts;
+    plan tests => 1 + $tests_per_env * $optscount;
 
     # Windows emulates the executable bit based on file extension only
     ok($^O eq "MSWin32" ? -f $nytprofcsv : -x $nytprofcsv, "Found nytprofcsv as $nytprofcsv");
@@ -368,9 +370,6 @@ sub run_test {
 
         verify_csv_report($test, $tag, $test_datafile, $outdir);
     }
-    elsif ($type eq 'pf') {
-        verify_platforms_csv_report($test, $tag, $test_datafile, $outdir);
-    }
     elsif ($type =~ /^(?:pl|pm|new|outdir)$/) {
         # skip; handy for "test.pl t/test01.*"
     }
@@ -674,28 +673,6 @@ sub verify_csv_report {
     is(join("\n", @accuracy_errors), '', "$test times should be reasonable");
 }
 
-sub verify_platforms_csv_report {
-    my ($test, $tag, $profile_datafile, $outdir) = @_;
-    
-    my $outfile = "$outdir/$test.csv";
-
-    my $cmd = "$perl $nytprofpf --file=$profile_datafile --out=$outfile";
-    ok run_command($cmd), "nytprofpf runs ok";
-
-    my $got = slurp_file($outfile);
-        
-    #test if all lines from .pf are contained in result file 
-    #(we can not be sure about the order, so we match each line individually)
-    my $match_result = 1;
-    open (EXPECTED, $test); 
-    while (<EXPECTED>) {
-        $match_result = $match_result && $got =~ m/$_/;
-    }
-    close (EXPECTED);    
-
-    ok $match_result, "$outfile file matches $test";
-}
-
 sub pop_times {
     my $hash = shift || return;
 
